@@ -1,6 +1,6 @@
 package OpenInteract::Template::Plugin;
 
-# $Id: Plugin.pm,v 1.25 2002/09/16 20:18:36 lachoy Exp $
+# $Id: Plugin.pm,v 1.26 2002/11/07 13:03:03 lachoy Exp $
 
 use strict;
 use base qw( Template::Plugin );
@@ -11,7 +11,7 @@ use SPOPS::Secure   qw( :level :scope );
 use SPOPS::Utility;
 use Text::Sentence;
 
-$OpenInteract::Template::Plugin::VERSION  = sprintf("%d.%02d", q$Revision: 1.25 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::Template::Plugin::VERSION  = sprintf("%d.%02d", q$Revision: 1.26 $ =~ /(\d+)\.(\d+)/);
 
 my %SECURITY_CONSTANTS  = (
   level => {
@@ -573,7 +573,7 @@ Example:
 
  [% OI.comp( 'error_display', error_msg = error_msg ) %]
 
-See L<OpenInteract::Component|OpenInteract::Component> package for
+See L<OpenInteract::Component|OpenInteract::Component> module for
 more information about components.
 
 B<box_add( $box, \%params )>
