@@ -2,8 +2,8 @@ CREATE TABLE content_type (
   content_type_id   %%INCREMENT%%,
   mime_type         varchar(40) not null,
   extensions        varchar(40) not null,
-  description       varchar(100) null,
-  image_source      varchar(50) null,
+  description       varchar(100),
+  image_source      varchar(50),
   PRIMARY KEY       ( content_type_id ),
   UNIQUE            ( mime_type )
 )
\ No newline at end of file
