@@ -5,7 +5,7 @@ CREATE TABLE object_track (
  action        varchar(10) default 'create',
  action_by     %%USERID_TYPE%% not null,
  action_on     datetime not null,
- notes         text null,
+ notes         text,
  primary key   ( objtrack_id ),
  unique        ( class, object_id, action, action_by, action_on )
 )
\ No newline at end of file
